@@ -1,3 +1,6 @@
+import logging
+import os
+
 from flask import Flask
 from flask_cors import CORS
 
@@ -6,6 +9,12 @@ from .config import Config
 from .error_handler import get_error_handler
 
 
+def quiet_mode() -> None:
+    """Remove the logging from Werkzeug."""
+    logging.getLogger("werkzeug").disabled = True
+    os.environ["WERKZEUG_RUN_MAIN"] = "true"
+
+
 def create_app(cfg: Config) -> Flask:
     """
     Create an instance of our API.
@@ -15,6 +24,8 @@ def create_app(cfg: Config) -> Flask:
     app.register_error_handler(Exception, get_error_handler(app.config["DEBUG"]))
     for blueprint in all_blueprints():
         app.register_blueprint(blueprint)
+    if app.config["QUIET"]:
+        quiet_mode()
     if app.config["DEBUG"]:
         CORS(app)
     return app
